
All notable changes to this project will be documented in this file.

## [0.1.1] - 2020-10-22

* Added tutorials for creating and deploying Rasa chatbots as well as creating a bot and generating API keys on the Robo AI platform.
* [#3](https://github.com/robo-ai/roboai-python-cli/issues/3): Fixed bug in the deployment command. Fixed minor bugs.

## [0.1.0] - 2020-10-14

* Initial version.
